@@ -29,7 +29,7 @@ class Puppet::DataBinding::Hiera < Puppet::Indirector::Code
     hiera_config = Puppet.settings[:hiera_config]
     config = {}
 
-    if Puppet::FileSystem::File.exist?(hiera_config)
+    if Puppet::FileSystem.exist?(hiera_config)
       config = Hiera::Config.load(hiera_config)
     else
       Puppet.warning "Config file #{hiera_config} not found, using Hiera defaults"
