@@ -35,6 +35,12 @@ class Puppet::Pops::Binder::KeyFactory
     "mc_#{multibind_id}"
   end
 
+  # @api public
+  def multibind_contribution_key_to_id(contributions_key)
+    # removes the leading "mc_" from the key to get the multibind_id
+    contributions_key[3..-1]
+  end
+
   # @api public
   def is_named?(key)
     key.is_a?(Array) && key[1] && !key[1].empty?
@@ -58,4 +64,4 @@ class Puppet::Pops::Binder::KeyFactory
     return nil unless key.is_a?(Array)
     key[0]
   end
-end
\ No newline at end of file
+end
