@@ -461,12 +461,16 @@ class Puppet::Pops::Model::Factory
     current.respond_to?(meth, include_all) || super
   end
 
+  def self.record_position(o, start_locatable, end_locateable)
+    new(o).record_position(start_locatable, end_locateable)
+  end
+
   # Records the position (start -> end) and computes the resulting length.
   #
   def record_position(start_locatable, end_locatable)
     from = start_locatable.is_a?(Puppet::Pops::Model::Factory) ? start_locatable.current : start_locatable
     to   = end_locatable.is_a?(Puppet::Pops::Model::Factory) ? end_locatable.current  : end_locatable
-    to = from if to.nil?
+    to = from if to.nil? || to.offset.nil?
     o = current
     # record information directly in the Model::Positioned object
     o.offset = from.offset
@@ -703,9 +707,9 @@ class Puppet::Pops::Model::Factory
     o.nil? || o.is_a?(Puppet::Pops::Model::Nop)
   end
 
-  STATEMENT_CALLS = { 
-    'require' => true, 
-    'realize' => true, 
+  STATEMENT_CALLS = {
+    'require' => true,
+    'realize' => true,
     'include' => true,
     'contain' => true,
 
@@ -716,6 +720,7 @@ class Puppet::Pops::Model::Factory
     'error'   => true,
 
     'fail'    => true,
+    'import'  => true  # discontinued, but transform it to make it call error reporting function
   }
   # Returns true if the given name is a "statement keyword" (require, include, contain,
   # error, notice, info, debug
@@ -732,7 +737,10 @@ class Puppet::Pops::Model::Factory
       expr = expr.current if expr.is_a?(Puppet::Pops::Model::Factory)
       name = memo[-1]
       if name.is_a?(Model::QualifiedName) && STATEMENT_CALLS[name.value]
-        memo[-1] = Puppet::Pops::Model::Factory.CALL_NAMED(name, false, expr.is_a?(Array) ? expr : [expr])
+        the_call = Puppet::Pops::Model::Factory.CALL_NAMED(name, false, expr.is_a?(Array) ? expr : [expr])
+        # last positioned is last arg if there are several
+        record_position(the_call, name, expr.is_a?(Array) ? expr[-1]  : expr)
+        memo[-1] = the_call
         if expr.is_a?(Model::CallNamedFunctionExpression)
           # Patch statement function call to expression style
           # This is needed because it is first parsed as a "statement" and the requirement changes as it becomes
