@@ -58,8 +58,7 @@ class Puppet::Pops::Parser::Lexer
     end
 
     # @return [Boolean] if the token is acceptable in the given context or not.
-    #   this implementation always returns true.
-    # @param context [Hash] ? ? ?
+    # @param context [Hash] the lexing context
     #
     def acceptable?(context={})
       @acceptable_when.call(context)
@@ -154,6 +153,7 @@ class Puppet::Pops::Parser::Lexer
   ')'   => :RPAREN,
   '='   => :EQUALS,
   '+='  => :APPENDS,
+  '-='  => :DELETES,
   '=='  => :ISEQUAL,
   '>='  => :GREATEREQUAL,
   '>'   => :GREATERTHAN,
@@ -213,13 +213,13 @@ class Puppet::Pops::Parser::Lexer
       REGEX_INTRODUCING_TOKENS.include? context[:after]
     end
 
-    DASHED_VARIABLES_ALLOWED = Proc.new do |context|
-      Puppet[:allow_variables_with_dashes]
-    end
-
-    VARIABLE_AND_DASHES_ALLOWED = Proc.new do |context|
-      Contextual::DASHED_VARIABLES_ALLOWED.call(context) and TOKENS[:VARIABLE].acceptable?(context)
-    end
+#    DASHED_VARIABLES_ALLOWED = Proc.new do |context|
+#      Puppet[:allow_variables_with_dashes]
+#    end
+#
+#    VARIABLE_AND_DASHES_ALLOWED = Proc.new do |context|
+#      Contextual::DASHED_VARIABLES_ALLOWED.call(context) and TOKENS[:VARIABLE].acceptable?(context)
+#    end
   end
 
   # Numbers are treated separately from names, so that they may contain dots.
@@ -252,14 +252,14 @@ class Puppet::Pops::Parser::Lexer
   end
 
   TOKENS.add_token :COMMENT, %r{#.*}, :skip => true do |lexer,value|
-    value.sub!(/# ?/,'')
-    [self, value]
+#    value.sub!(/# ?/,'')
+    [self, ""]
   end
 
   TOKENS.add_token :MLCOMMENT, %r{/\*(.*?)\*/}m, :skip => true do |lexer, value|
-    value.sub!(/^\/\* ?/,'')
-    value.sub!(/ ?\*\/$/,'')
-    [self,value]
+#    value.sub!(/^\/\* ?/,'')
+#    value.sub!(/ ?\*\/$/,'')
+    [self, ""]
   end
 
   TOKENS.add_token :REGEX, %r{/[^/\n]*/} do |lexer, value|
@@ -312,30 +312,10 @@ class Puppet::Pops::Parser::Lexer
     end
   end
 
-  TOKENS.add_token :DOLLAR_VAR_WITH_DASH, %r{\$(?:::)?(?:[-\w]+::)*[-\w]+} do |lexer, value|
-    lexer.warn_if_variable_has_hyphen(value)
-
-    [TOKENS[:VARIABLE], value[1..-1]]
-  end
-  TOKENS[:DOLLAR_VAR_WITH_DASH].acceptable_when Contextual::DASHED_VARIABLES_ALLOWED
-
   TOKENS.add_token :DOLLAR_VAR, %r{\$(::)?(\w+::)*\w+} do |lexer, value|
     [TOKENS[:VARIABLE],value[1..-1]]
   end
 
-  TOKENS.add_token :VARIABLE_WITH_DASH, %r{(?:::)?(?:[-\w]+::)*[-\w]+} do |lexer, value|
-    lexer.warn_if_variable_has_hyphen(value)
-    # If the varname (following $, or ${ is followed by (, it is a function call, and not a variable
-    # reference.
-    #
-    if lexer.match?(%r{[ \t\r]*\(})
-      [TOKENS[:NAME],value]
-    else
-      [TOKENS[:VARIABLE], value]
-    end
-  end
-  TOKENS[:VARIABLE_WITH_DASH].acceptable_when Contextual::VARIABLE_AND_DASHES_ALLOWED
-
   TOKENS.add_token :VARIABLE, %r{(::)?(\w+::)*\w+} do |lexer, value|
     # If the varname (following $, or ${ is followed by (, it is a function call, and not a variable
     # reference.
@@ -418,9 +398,9 @@ class Puppet::Pops::Parser::Lexer
 
   def file=(file)
     @file = file
-    contents = Puppet::FileSystem::File.exist?(file) ? File.read(file) : ""
-    @scanner = StringScanner.new(contents)
-    @locator = Locator.new(contents, multibyte?)
+    contents = Puppet::FileSystem.exist?(file) ? Puppet::FileSystem.read(file) : ""
+    @scanner = StringScanner.new(contents.freeze)
+    @locator = Puppet::Pops::Parser::Locator.locator(contents, file)
   end
 
   def_delegator :@token_queue, :shift, :shift_token
@@ -431,9 +411,13 @@ class Puppet::Pops::Parser::Lexer
     # tries, where it is otherwise the number of string token we have.  Also,
     # the lookups are optimized hash lookups, instead of regex scans.
     #
-    s = @scanner.peek(3)
+    _scn = @scanner
+    s = _scn.peek(3)
     token = TOKENS.lookup(s[0,3]) || TOKENS.lookup(s[0,2]) || TOKENS.lookup(s[0,1])
-    [ token, token && @scanner.scan(token.regex) ]
+    unless token
+      return [nil, nil]
+    end
+    [ token, _scn.scan(token.regex) ]
   end
 
   # Find the next token that matches a regex.  We look for these first.
@@ -443,8 +427,10 @@ class Puppet::Pops::Parser::Lexer
 
     # I tried optimizing based on the first char, but it had
     # a slightly negative affect and was a good bit more complicated.
+    _lxc = @lexing_context
+    _scn = @scanner
     TOKENS.regex_tokens.each do |token|
-      if length = @scanner.match?(token.regex) and token.acceptable?(lexing_context)
+      if length = _scn.match?(token.regex) and token.acceptable?(_lxc)
         # We've found a longer match
         if length > best_length
           best_length = length
@@ -453,7 +439,7 @@ class Puppet::Pops::Parser::Lexer
       end
     end
 
-    return best_token, @scanner.scan(best_token.regex) if best_token
+    return best_token, _scn.scan(best_token.regex) if best_token
   end
 
   # Find the next token, returning the string and the token.
@@ -461,8 +447,10 @@ class Puppet::Pops::Parser::Lexer
     shift_token || find_regex_token || find_string_token
   end
 
+  MULTIBYTE = Puppet::Pops::Parser::Locator::MULTIBYTE
+  SKIPPATTERN = MULTIBYTE ? %r{[[:blank:]\r]+} : %r{[ \t\r]+}
+
   def initialize
-    @multibyte = init_multibyte
     initvars
   end
 
@@ -476,21 +464,6 @@ class Puppet::Pops::Parser::Lexer
     end
   end
 
-  # Returns true if ruby version >= 1.9.3 since regexp supports multi-byte matches and expanded
-  # character categories like [[:blank:]].
-  #
-  # This implementation will fail if there are more than 255 minor or micro versions of ruby
-  #
-  def init_multibyte
-    numver = RUBY_VERSION.split(".").collect {|s| s.to_i }
-    return true if (numver[0] << 16 | numver[1] << 8 | numver[2]) >= (1 << 16 | 9 << 8 | 3)
-    false
-  end
-
-  def multibyte?
-    @multibyte
-  end
-
   def initvars
     @previous_token = nil
     @scanner = nil
@@ -499,13 +472,6 @@ class Puppet::Pops::Parser::Lexer
     # AAARRGGGG! okay, regexes in ruby are bloody annoying
     # no one else has "\n" =~ /\s/
 
-    if multibyte?
-      # Skip all kinds of space, and CR, but not newlines
-      @skip = %r{[[:blank:]\r]+}
-    else
-      @skip = %r{[ \t\r]+}
-    end
-
     @namestack = []
     @token_queue = []
     @indefine = false
@@ -526,7 +492,7 @@ class Puppet::Pops::Parser::Lexer
     #
     return token, value if value.is_a? Hash
 
-    skip if token.skip_text
+    @scanner.skip(SKIPPATTERN) if token.skip_text
 
     return if token.skip
 
@@ -539,26 +505,22 @@ class Puppet::Pops::Parser::Lexer
     # If the conversion performed the munging/positioning
     return token, value if value.is_a? Hash
 
-    pos_hash = position_in_source
-    pos_hash[:value] = value
-
-    # Add one to pos, first char on line is 1
-    return token, pos_hash
+    return token, positioned_value(value)
   end
 
   # Returns a hash with the current position in source based on the current lexing context
   #
-  def position_in_source
-    pos        = @locator.pos_on_line(lexing_context[:offset])
-    offset     = @locator.char_offset(lexing_context[:offset])
-    length     = @locator.char_length(lexing_context[:offset], lexing_context[:end_offset])
-    start_line = @locator.line_for_offset(lexing_context[:offset])
-
-    return { :line => start_line, :pos => pos, :offset => offset, :length => length}
+  def positioned_value(value)
+    {
+      :value => value,
+      :locator => @locator,
+      :offset => @lexing_context[:offset],
+      :end_offset => @lexing_context[:end_offset]
+    }
   end
 
   def pos
-    @locator.pos_on_line(lexing_context[:offset])
+    @locator.pos_on_line(@lexing_context[:offset])
   end
 
   # Handling the namespace stack
@@ -575,58 +537,67 @@ class Puppet::Pops::Parser::Lexer
   end
 
   def_delegator :@scanner, :rest
+
+  LBRACE_CHAR = '{'
+
   # this is the heart of the lexer
   def scan
+    _scn = @scanner
     #Puppet.debug("entering scan")
-    lex_error "Internal Error: No string or file given to lexer to process." unless @scanner
+    lex_error "Internal Error: No string or file given to lexer to process." unless _scn
 
     # Skip any initial whitespace.
-    skip
+    _scn.skip(SKIPPATTERN)
+    _lbrace = '{'.freeze  # faster to compare against a frozen string in
 
-    until token_queue.empty? and @scanner.eos? do
-      offset = @scanner.pos
+    until token_queue.empty? and _scn.eos? do
+      offset = _scn.pos
       matched_token, value = find_token
-      end_offset = @scanner.pos
+      end_offset = _scn.pos
 
       # error out if we didn't match anything at all
-      lex_error "Could not match #{@scanner.rest[/^(\S+|\s+|.*)/]}" unless matched_token
+      lex_error "Could not match #{_scn.rest[/^(\S+|\s+|.*)/]}" unless matched_token
 
       newline = matched_token.name == :RETURN
 
-      lexing_context[:start_of_line] = newline
-      lexing_context[:offset] = offset
-      lexing_context[:end_offset] = end_offset
+      _lxc = @lexing_context
+      _lxc[:start_of_line] = newline
+      _lxc[:offset] = offset
+      _lxc[:end_offset] = end_offset
 
       final_token, token_value = munge_token(matched_token, value)
       # update end position since munging may have moved the end offset
-      lexing_context[:end_offset] = @scanner.pos
+      _lxc[:end_offset] = _scn.pos
 
       unless final_token
-        skip
+        _scn.skip(SKIPPATTERN)
         next
       end
 
-      lexing_context[:after] = final_token.name unless newline
+      _lxc[:after] = final_token.name unless newline
       if final_token.name == :DQPRE
-        lexing_context[:interpolation_stack] << lexing_context[:brace_count]
+        _lxc[:interpolation_stack] << _lxc[:brace_count]
       elsif final_token.name == :DQPOST
-        lexing_context[:interpolation_stack].pop
+        _lxc[:interpolation_stack].pop
       end
 
       value = token_value[:value]
 
+      _expected = @expected
       if match = @@pairs[value] and final_token.name != :DQUOTE and final_token.name != :SQUOTE
-        @expected << match
-      elsif exp = @expected[-1] and exp == value and final_token.name != :DQUOTE and final_token.name != :SQUOTE
-        @expected.pop
+        _expected << match
+      elsif exp = _expected[-1] and exp == value and final_token.name != :DQUOTE and final_token.name != :SQUOTE
+        _expected.pop
       end
 
       yield [final_token.name, token_value]
 
-      if @previous_token
-        namestack(value) if @previous_token.name == :CLASS and value != '{'
+      _prv = @previous_token
+      if _prv
+        namestack(value) if _prv.name == :CLASS and value != LBRACE_CHAR
 
-        if @previous_token.name == :DEFINE
+        # TODO: Lexer has no business dealing with this - it is semantic
+        if _prv.name == :DEFINE
           if indefine?
             msg = "Cannot nest definition #{value} inside #{@indefine}"
             self.indefine = false
@@ -637,7 +608,7 @@ class Puppet::Pops::Parser::Lexer
         end
       end
       @previous_token = final_token
-      skip
+      _scn.skip(SKIPPATTERN)
     end
     # Cannot reset @scanner to nil here - it is needed to answer questions about context after
     # completed parsing.
@@ -648,11 +619,6 @@ class Puppet::Pops::Parser::Lexer
     yield [false,false]
   end
 
-  # Skip any skipchars in our remaining string.
-  def skip
-    @scanner.skip(@skip)
-  end
-
   def match? r
     @scanner.match?(r)
   end
@@ -721,9 +687,10 @@ class Puppet::Pops::Parser::Lexer
     # Advanced after '{' if this is in expression ${} interpolation
     braced = terminator == '$' && @scanner.scan(/\{/)
     # make offset to end_ofset be the length of the pre expression string including its start and terminating chars
-    lexing_context[:end_offset] = @scanner.pos
+    lxc = @lexing_context
+    lxc[:end_offset] = @scanner.pos
 
-    token_queue << [TOKENS[token_type[terminator]],position_in_source().merge!({:value => preamble+value})]
+    token_queue << [TOKENS[token_type[terminator]],positioned_value(preamble+value)]
     variable_regex = if Puppet[:allow_variables_with_dashes]
       TOKENS[:VARIABLE_WITH_DASH].regex
     else
@@ -735,18 +702,18 @@ class Puppet::Pops::Parser::Lexer
 
     tmp_offset = @scanner.pos
     if var_name = @scanner.scan(variable_regex)
-      lexing_context[:offset] = tmp_offset
-      lexing_context[:end_offset] = @scanner.pos
+      lxc[:offset] = tmp_offset
+      lxc[:end_offset] = @scanner.pos
       warn_if_variable_has_hyphen(var_name)
       # If the varname after ${ is followed by (, it is a function call, and not a variable
       # reference.
       #
       if braced && @scanner.match?(%r{[ \t\r]*\(})
-        token_queue << [TOKENS[:NAME], position_in_source().merge!({:value=>var_name})]
+        token_queue << [TOKENS[:NAME], positioned_value(var_name)]
       else
-        token_queue << [TOKENS[:VARIABLE],position_in_source().merge!({:value=>var_name})]
+        token_queue << [TOKENS[:VARIABLE],positioned_value(var_name)]
       end
-      lexing_context[:offset] = @scanner.pos
+      lxc[:offset] = @scanner.pos
       tokenize_interpolated_string(DQ_continuation_token_types)
     else
       tokenize_interpolated_string(token_type, replace_false_start_with_text(terminator))
@@ -764,9 +731,9 @@ class Puppet::Pops::Parser::Lexer
   end
 
   # just parse a string, not a whole file
-  def string=(string)
-    @scanner = StringScanner.new(string)
-    @locator = Locator.new(string, multibyte?)
+  def string=(string, path='')
+    @scanner = StringScanner.new(string.freeze)
+    @locator = Puppet::Pops::Parser::Locator.locator(string, path)
   end
 
   def warn_if_variable_has_hyphen(var_name)
@@ -780,83 +747,7 @@ class Puppet::Pops::Parser::Lexer
   # consumed.
   #
   def line
-    return 1 unless lexing_context && locator
-    locator.line_for_offset(lexing_context[:end_offset])
-  end
-
-  # Helper class that keeps track of where line breaks are located and can answer questions about positions.
-  #
-  class Locator
-    attr_reader :line_index
-    attr_reader :string
-
-    # Create a locator based on a content string, and a boolean indicating if ruby version support multi-byte strings
-    # or not.
-    #
-    def initialize(string, multibyte)
-      @string = string
-      @multibyte = multibyte
-      compute_line_index
-    end
-
-    # Returns whether this a ruby version that supports multi-byte strings or not
-    #
-    def multibyte?
-      @multibyte
-    end
-
-    # Computes the start offset for each line.
-    #
-    def compute_line_index
-      scanner = StringScanner.new(@string)
-      result = [0] # first line starts at 0
-      while scanner.scan_until(/\n/)
-        result << scanner.pos
-      end
-      @line_index = result
-    end
-
-    # Returns the line number (first line is 1) for the given offset
-    def line_for_offset(offset)
-      if line_nbr = line_index.index {|x| x > offset}
-        return line_nbr
-      end
-      # If not found it is after last
-      return line_index.size
-    end
-
-    # Returns the offset on line (first offset on a line is 0).
-    #
-    def offset_on_line(offset)
-      line_offset = line_index[line_for_offset(offset)-1]
-      if multibyte?
-        @string.byteslice(line_offset, offset-line_offset).length
-      else
-        offset - line_offset
-      end
-    end
-
-    # Returns the position on line (first position on a line is 1)
-    def pos_on_line(offset)
-      offset_on_line(offset) +1
-    end
-
-    # Returns the character offset for a given byte offset
-    def char_offset(byte_offset)
-      if multibyte?
-        @string.byteslice(0, byte_offset).length
-      else
-        byte_offset
-      end
-    end
-
-    # Returns the length measured in number of characters from the given start and end byte offseta
-    def char_length(offset, end_offset)
-      if multibyte?
-        @string.byteslice(offset, end_offset - offset).length
-      else
-        end_offset - offset
-      end
-    end
+    return 1 unless @lexing_context && locator
+    locator.line_for_offset(@lexing_context[:end_offset])
   end
 end
