@@ -180,6 +180,11 @@ class Puppet::Pops::Types::TypeParser
 
     when "struct"
       TYPES.struct()
+
+    when "callable"
+      # A generic callable as opposed to one that does not accept arguments
+      TYPES.all_callables()
+
     else
       TYPES.resource(name_ast.value)
     end
@@ -329,6 +334,10 @@ class Puppet::Pops::Types::TypeParser
       end
       t
 
+    when "callable"
+      # 1..m parameters being types (last three optionally integer or literal default, and a callable)
+      TYPES.callable(*parameters)
+
     when "struct"
       # 1..m parameters being types (last two optionally integer or literal default
       raise_invalid_parameters_error("Struct", "1", parameters.size) unless parameters.size == 1
