@@ -15,6 +15,9 @@ require 'rgen/metamodel_builder'
 # @api public
 #
 module Puppet::Pops::Types
+  # Used as end in a range
+  INFINITY = 1.0 / 0.0
+  NEGATIVE_INFINITY = -INFINITY
 
   class PAbstractType < Puppet::Pops::Model::PopsObject
     abstract
@@ -134,15 +137,15 @@ module Puppet::Pops::Types
 
       # Returns Float.Infinity if one end of the range is unbound
       def size
-        return 1.0 / 0.0 if from.nil? || to.nil?
+        return INFINITY if from.nil? || to.nil?
         1+(to-from).abs
       end
 
       # Returns the range as an array ordered so the smaller number is always first.
       # The number may be Infinity or -Infinity.
       def range
-        f = from || -(1.0 / 0.0)
-        t = to || (1.0 / 0.0)
+        f = from || NEGATIVE_INFINITY
+        t = to || INFINITY
         if f < t
           [f, t]
         else
@@ -253,9 +256,23 @@ module Puppet::Pops::Types
   class PCollectionType < PObjectType
     contains_one_uni 'element_type', PAbstractType
     contains_one_uni 'size_type', PIntegerType
+
     module ClassModule
+      # Returns an array with from (min) size to (max) size
+      # A negative range value in from is 
+      def size_range
+        return [0, INFINITY] if size_type.nil?
+        f = size_type.from || 0
+        t = size_type.to || INFINITY
+        if f < t
+          [f, t]
+        else
+          [t,f]
+        end
+      end
+
       def hash
-        [self.class, element_type, size].hash
+        [self.class, element_type, size_type].hash
       end
 
       def ==(o)
@@ -344,6 +361,50 @@ module Puppet::Pops::Types
     end
   end
 
+  class PCallableType < PObjectType
+    # Types of parameters and required/optional count
+    contains_one_uni 'param_types', PTupleType, :lowerBound => 1
+
+    # Although being an abstract type reference, only PAbstractCallable, and Optional[Callable] are supported
+    # If not set, the meaning is that block is not supported.
+    #
+    contains_one_uni 'block_type', PAbstractType, :lowerBound => 0
+
+    module ClassModule
+      # Returns the number of accepted arguments [min, max]
+      def size_range
+        param_types.size_range
+      end
+
+      # Returns the number of accepted arguments for the last parameter type [min, max]
+      #
+      def last_range
+        param_types.repeat_last_range
+      end
+
+      # Range [0,0], [0,1], or [1,1] for the block
+      #
+      def block_range
+        case block_type
+        when Puppet::Pops::Types::POptionalType
+          [0,1]
+        when Puppet::Pops::Types::PVariantType, Puppet::Pops::Types::PCallableType
+          [1,1]
+        else
+          [0,0]
+        end
+      end
+
+      def hash
+        [self.class, Set.new(param_types), block_type].hash
+      end
+
+      def ==(o)
+        self.class == o.class && args_type == o.args_type && block_type == o.block_type
+      end
+    end
+  end
+
   # @api public
   class PArrayType < PCollectionType
     module ClassModule
