@@ -71,7 +71,7 @@ Puppet::Type.type(:service).provide :freebsd, :parent => :init do
     success = false
     # Replace in all files, not just in the first found with a match
     [rcconf, rcconf_local, rcconf_dir + "/#{service}"].each do |filename|
-      if File.exists?(filename)
+      if Puppet::FileSystem.exist?(filename)
         s = File.read(filename)
         if s.gsub!(/^(#{rcvar}(_enable)?)=\"?(YES|NO)\"?/, "\\1=\"#{yesno}\"")
           File.open(filename, File::WRONLY) { |f| f << s }
@@ -87,14 +87,14 @@ Puppet::Type.type(:service).provide :freebsd, :parent => :init do
   def rc_add(service, rcvar, yesno)
     append = "\# Added by Puppet\n#{rcvar}_enable=\"#{yesno}\"\n"
     # First, try the one-file-per-service style
-    if File.exists?(rcconf_dir)
+    if Puppet::FileSystem.exist?(rcconf_dir)
       File.open(rcconf_dir + "/#{service}", File::WRONLY | File::APPEND | File::CREAT, 0644) {
         |f| f << append
         self.debug("Appended to #{f.path}")
       }
     else
       # Else, check the local rc file first, but don't create it
-      if File.exists?(rcconf_local)
+      if Puppet::FileSystem.exist?(rcconf_local)
         File.open(rcconf_local, File::WRONLY | File::APPEND) {
           |f| f << append
           self.debug("Appended to #{f.path}")
