@@ -250,7 +250,7 @@ Puppet::Type.newtype(:file) do
     desc "Whether to display differences when the file changes, defaulting to
         true.  This parameter is useful for files that may contain passwords or
         other secret data, which might otherwise be included in Puppet reports or
-        other insecure outputs.  If the global ``show_diff` setting
+        other insecure outputs.  If the global `show_diff` setting
         is false, then no diffs will be shown even if this parameter is true."
 
     defaultto :true
@@ -613,7 +613,9 @@ Puppet::Type.newtype(:file) do
       end
       children[meta.relative_path] ||= newchild(meta.relative_path)
       children[meta.relative_path][:source] = meta.source
-      children[meta.relative_path][:checksum] = :md5 if meta.ftype == "file"
+      if meta.ftype == "file"
+        children[meta.relative_path][:checksum] = Puppet[:digest_algorithm].to_sym
+      end
 
       children[meta.relative_path].parameter(:source).metadata = meta
     end
