@@ -59,6 +59,7 @@ class HavePrintedMatcher
   def matches?(block)
     begin
       $stderr = $stdout = StringIO.new
+      $stdout.set_encoding('UTF-8') if $stdout.respond_to?(:set_encoding)
       block.call
       $stdout.rewind
       @actual = $stdout.read
@@ -87,6 +88,10 @@ class HavePrintedMatcher
     end
   end
 
+  def failure_message_for_should_not
+    "expected #{@expected.inspect} to not be printed; got:\n#{@actual}"
+  end
+
   def description
     "expect #{@expected.inspect} to be printed"
   end
