@@ -6,6 +6,10 @@ require 'puppet/configurer/downloader'
 describe Puppet::Configurer::Downloader do
   require 'puppet_spec/files'
   include PuppetSpec::Files
+
+  let(:path)   { Puppet[:plugindest] }
+  let(:source) { 'puppet://puppet/plugins' }
+
   it "should require a name" do
     lambda { Puppet::Configurer::Downloader.new }.should raise_error(ArgumentError)
   end
@@ -21,87 +25,115 @@ describe Puppet::Configurer::Downloader do
     dler.source.should == "source"
   end
 
-  describe "when creating the file that does the downloading" do
-    before do
-      @dler = Puppet::Configurer::Downloader.new("foo", "path", "source")
-    end
+  def downloader(options = {})
+    options[:name] ||= "facts"
+    options[:path] ||= path
+    options[:source_permissions] ||= :ignore
+    Puppet::Configurer::Downloader.new(options[:name], options[:path], source, options[:ignore], options[:environment], options[:source_permissions])
+  end
 
+  def generate_file_resource(options = {})
+    dler = downloader(options)
+    dler.file
+  end
+
+  describe "when creating the file that does the downloading" do
     it "should create a file instance with the right path and source" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:path] == "path" and opts[:source] == "source" }
-      @dler.file
+      file = generate_file_resource(:path => path, :source => source)
+
+      expect(file[:path]).to eq(path)
+      expect(file[:source]).to eq([source])
     end
 
     it "should tag the file with the downloader name" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:tag] == "foo" }
-      @dler.file
+      name = "mydownloader"
+      file = generate_file_resource(:name => name)
+
+      expect(file[:tag]).to eq([name])
     end
 
     it "should always recurse" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:recurse] == true }
-      @dler.file
+      file = generate_file_resource
+
+      expect(file[:recurse]).to be_true
     end
 
     it "should always purge" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:purge] == true }
-      @dler.file
+      file = generate_file_resource
+
+      expect(file[:purge]).to be_true
     end
 
     it "should never be in noop" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:noop] == false }
-      @dler.file
+      file = generate_file_resource
+
+      expect(file[:noop]).to be_false
     end
 
-    it "should set source_permissions to ignore" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:source_permissions] == :ignore }
-      @dler.file
+    it "should set source_permissions to ignore by default" do
+      file = generate_file_resource
+
+      expect(file[:source_permissions]).to eq(:ignore)
+    end
+
+    it "should allow source_permissions to be overridden" do
+      file = generate_file_resource(:source_permissions => :use)
+
+      expect(file[:source_permissions]).to eq(:use)
     end
 
     describe "on POSIX", :as_platform => :posix do
       it "should always set the owner to the current UID" do
         Process.expects(:uid).returns 51
-        Puppet::Type.type(:file).expects(:new).with { |opts| opts[:owner] == 51 }
-        @dler.file
+
+        file = generate_file_resource(:path => '/path')
+        expect(file[:owner]).to eq(51)
       end
 
       it "should always set the group to the current GID" do
         Process.expects(:gid).returns 61
-        Puppet::Type.type(:file).expects(:new).with { |opts| opts[:group] == 61 }
-        @dler.file
+
+        file = generate_file_resource(:path => '/path')
+        expect(file[:group]).to eq(61)
       end
     end
 
     describe "on Windows", :as_platform => :windows do
       it "should omit the owner" do
-        Puppet::Type.type(:file).expects(:new).with { |opts| opts[:owner] == nil }
-        @dler.file
+        file = generate_file_resource(:path => 'C:/path')
+
+        expect(file[:owner]).to be_nil
       end
 
       it "should omit the group" do
-        Puppet::Type.type(:file).expects(:new).with { |opts| opts[:group] == nil }
-        @dler.file
+        file = generate_file_resource(:path => 'C:/path')
+
+        expect(file[:group]).to be_nil
       end
     end
 
     it "should always force the download" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:force] == true }
-      @dler.file
+      file = generate_file_resource
+
+      expect(file[:force]).to be_true
     end
 
     it "should never back up when downloading" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:backup] == false }
-      @dler.file
+      file = generate_file_resource
+
+      expect(file[:backup]).to be_false
     end
 
     it "should support providing an 'ignore' parameter" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:ignore] == [".svn"] }
-      @dler = Puppet::Configurer::Downloader.new("foo", "path", "source", ".svn")
-      @dler.file
+      file = generate_file_resource(:ignore => '.svn')
+
+      expect(file[:ignore]).to eq(['.svn'])
     end
 
     it "should split the 'ignore' parameter on whitespace" do
-      Puppet::Type.type(:file).expects(:new).with { |opts| opts[:ignore] == %w{.svn CVS} }
-      @dler = Puppet::Configurer::Downloader.new("foo", "path", "source", ".svn CVS")
-      @dler.file
+      file = generate_file_resource(:ignore => '.svn CVS')
+
+      expect(file[:ignore]).to eq(['.svn', 'CVS'])
     end
   end
 
