@@ -12,7 +12,7 @@ describe Puppet::FileSystem::Tempfile do
       file.write("stuff")
       file.flush
 
-      expect(Puppet::FileSystem::File.new(file.path).read).to eq("stuff")
+      expect(Puppet::FileSystem.read(file.path)).to eq("stuff")
     end
   end
 
@@ -29,7 +29,7 @@ describe Puppet::FileSystem::Tempfile do
       file.path
     end
 
-    expect(Puppet::FileSystem::File.new(filename).exist?).to be_false
+    expect(Puppet::FileSystem.exist?(filename)).to be_false
   end
 
   it "unlinks the temporary file even if the block raises an error" do
@@ -43,6 +43,6 @@ describe Puppet::FileSystem::Tempfile do
     rescue
     end
 
-    expect(Puppet::FileSystem::File.new(filename).exist?).to be_false
+    expect(Puppet::FileSystem.exist?(filename)).to be_false
   end
 end
