@@ -5,8 +5,7 @@ require 'puppet/network/authconfig'
 
 describe Puppet::Network::AuthConfig do
   before :each do
-    stub_file = stub('file', :stat => stub('stat', :ctime => :now))
-    Puppet::FileSystem::File.stubs(:new).returns stub_file
+    Puppet::FileSystem.stubs(:stat).returns stub('stat', :ctime => :now)
     Time.stubs(:now).returns Time.now
 
     Puppet::Network::AuthConfig.any_instance.stubs(:exists?).returns(true)
@@ -102,9 +101,9 @@ describe Puppet::Network::AuthConfig do
         :authenticated => true
       }
 
-      Puppet::Network::Rights.any_instance.expects(:is_request_forbidden_and_why?).with("path", :save, "to/resource", params)
+      Puppet::Network::Rights.any_instance.expects(:is_request_forbidden_and_why?).with(:save, "/path/to/resource", params)
 
-      described_class.new.check_authorization("path", :save, "to/resource", params)
+      described_class.new.check_authorization(:save, "/path/to/resource", params)
     end
   end
 end
