@@ -8,13 +8,6 @@ describe "Puppet::Network::HTTP::RackREST", :if => Puppet.features.rack? do
     Puppet::Network::HTTP::RackREST.ancestors.should be_include(Puppet::Network::HTTP::Handler)
   end
 
-  describe "when initializing" do
-    it "should call the Handler's initialization hook with its provided arguments" do
-      Puppet::Network::HTTP::RackREST.any_instance.expects(:initialize_for_puppet).with(:server => "my", :handler => "arguments")
-      Puppet::Network::HTTP::RackREST.new(:server => "my", :handler => "arguments")
-    end
-  end
-
   describe "when serving a request" do
     before :all do
       @model_class = stub('indirected model class')
@@ -31,25 +24,32 @@ describe "Puppet::Network::HTTP::RackREST", :if => Puppet.features.rack? do
       Rack::Request.new(env)
     end
 
+    let(:minimal_certificate) do
+        cert = OpenSSL::X509::Certificate.new
+        cert.version = 2
+        cert.serial = 0
+        cert.not_before = Time.now
+        cert.not_after = Time.now + 3600
+        cert.public_key = OpenSSL::PKey::RSA.new(512)
+        cert.subject = OpenSSL::X509::Name.parse("/CN=testing")
+        cert
+    end
+
     describe "#headers" do
       it "should return the headers (parsed from env with prefix 'HTTP_')" do
         req = mk_req('/', {'HTTP_Accept' => 'myaccept',
                            'HTTP_X_Custom_Header' => 'mycustom',
                            'NOT_HTTP_foo' => 'not an http header'})
         @handler.headers(req).should == {"accept" => 'myaccept',
-                                         "x-custom-header" => 'mycustom'}
+                                         "x-custom-header" => 'mycustom',
+                                         "content-type" => nil }
       end
     end
 
     describe "and using the HTTP Handler interface" do
-      it "should return the HTTP_ACCEPT parameter as the accept header" do
-        req = mk_req('/', 'HTTP_ACCEPT' => 'myaccept')
-        @handler.accept_header(req).should == "myaccept"
-      end
-
       it "should return the CONTENT_TYPE parameter as the content type header" do
         req = mk_req('/', 'CONTENT_TYPE' => 'mycontent')
-        @handler.content_type_header(req).should == "mycontent"
+        @handler.headers(req)['content-type'].should == "mycontent"
       end
 
       it "should use the REQUEST_METHOD as the http method" do
@@ -67,24 +67,15 @@ describe "Puppet::Network::HTTP::RackREST", :if => Puppet.features.rack? do
         @handler.body(req).should == "mybody"
       end
 
-      it "should return the an OpenSSL::X509::Certificate instance as the client_cert" do
-        cert = stub 'cert'
-        req = mk_req('/foo/bar', 'SSL_CLIENT_CERT' => 'certificate in pem format')
-        OpenSSL::X509::Certificate.expects(:new).with('certificate in pem format').returns(cert)
-        @handler.client_cert(req).should == cert
+      it "should return the an Puppet::SSL::Certificate instance as the client_cert" do
+        req = mk_req('/foo/bar', 'SSL_CLIENT_CERT' => minimal_certificate.to_pem)
+        expect(@handler.client_cert(req).content.to_pem).to eq(minimal_certificate.to_pem)
       end
 
       it "returns nil when SSL_CLIENT_CERT is empty" do
-        cert = stub 'cert'
         req = mk_req('/foo/bar', 'SSL_CLIENT_CERT' => '')
-        OpenSSL::X509::Certificate.expects(:new).never
-        @handler.client_cert(req).should be_nil
-      end
 
-      it "(#16769) does not raise error 'header too long'" do
-        cert = stub 'cert'
-        req = mk_req('/foo/bar', 'SSL_CLIENT_CERT' => '')
-        lambda { @handler.client_cert(req) }.should_not raise_error
+        @handler.client_cert(req).should be_nil
       end
 
       it "should set the response's content-type header when setting the content type" do
@@ -134,7 +125,8 @@ describe "Puppet::Network::HTTP::RackREST", :if => Puppet.features.rack? do
       it "should ensure the body has been partially read on failure" do
         req = mk_req('/production/report/foo')
         req.body.expects(:read).with(1)
-        req.stubs(:check_authorization).raises(Exception)
+
+        @handler.stubs(:headers).raises(Exception)
 
         @handler.process(req, @response)
       end
