@@ -1,11 +1,14 @@
 require 'spec_helper'
+require 'puppet_spec/scope'
 
 describe 'Puppet::Parser::Functions#hiera_array' do
+  include PuppetSpec::Scope
+
   before :each do
     Puppet[:hiera_config] = PuppetSpec::Files.tmpfile('hiera_config')
   end
 
-  let :scope do Puppet::Parser::Scope.new_for_test_harness('foo') end
+  let :scope do create_test_scope_for_node('foo') end
 
   it 'should require a key argument' do
     expect { scope.function_hiera_array([]) }.to raise_error(ArgumentError)
@@ -17,7 +20,7 @@ describe 'Puppet::Parser::Functions#hiera_array' do
   end
 
   it 'should use the array resolution_type' do
-    Hiera.any_instance.expects(:lookup).with() { |*args| args[4].should be :array }.returns([])
+    Hiera.any_instance.expects(:lookup).with() { |*args| args[4].should be(:array) }.returns([])
     scope.function_hiera_array(['key'])
   end
 end
