@@ -17,6 +17,10 @@ describe provider_class do
     provider
   end
 
+  before :each do
+    resource.provider = provider
+  end
+
   describe "when installing" do
     it "should use the path to the gem" do
       provider_class.stubs(:command).with(:gemcmd).returns "/my/gem"
@@ -44,6 +48,17 @@ describe provider_class do
       provider.install
     end
 
+    it "should not append install_options by default" do
+      provider.expects(:execute).with { |args| args.length == 5 }.returns ""
+      provider.install
+    end
+
+    it "should allow setting an install_options parameter" do
+      resource[:install_options] = [ '--force', {'--bindir' => '/usr/bin' } ]
+      provider.expects(:execute).with { |args| args[5] == '--force' && args[6] == '--bindir=/usr/bin' }.returns ''
+      provider.install
+    end
+
     describe "when a source is specified" do
       describe "as a normal file" do
         it "should use the file name instead of the gem name" do
