@@ -467,31 +467,31 @@ describe Puppet::Type.type(:user) do
         res.catalog = Puppet::Resource::Catalog.new
         res
       end
-      it "should not just return from eval_generate" do
+      it "should not just return from generate" do
         subject.expects :find_unmanaged_keys
-        subject.eval_generate
+        subject.generate
       end
       it "should check each keyfile for readability" do
         paths.each do |path|
           File.expects(:readable?).with(path)
         end
-        subject.eval_generate
+        subject.generate
       end
     end
 
     describe "generated keys" do
       subject do
-        res = described_class.new(:name => "test", :purge_ssh_keys => purge_param)
+        res = described_class.new(:name => "test_user_name", :purge_ssh_keys => purge_param)
         res.catalog = Puppet::Resource::Catalog.new
         res
       end
       context "when purging is disabled" do
         let(:purge_param) { false }
-        its(:eval_generate) { should be_empty }
+        its(:generate) { should be_empty }
       end
       context "when purging is enabled" do
         let(:purge_param) { my_fixture('authorized_keys') }
-        let(:resources) { subject.eval_generate }
+        let(:resources) { subject.generate }
         it "should contain a resource for each key" do
           names = resources.collect { |res| res.name }
           names.should include("keyname1")
@@ -501,6 +501,13 @@ describe Puppet::Type.type(:user) do
           names = resources.collect { |res| res.name }
           names.should_not include("keyname3")
         end
+        it "should each have a value for the user property" do
+          resources.map { |res|
+            res[:user]
+          }.reject { |user_name|
+            user_name == "test_user_name"
+          }.should be_empty
+        end
       end
     end
   end
